use std::fmt::Display;

#[derive(Debug)]
pub enum AuthError {
    NoPermssions,
    InvalidToken,
    Unexpected,
    InvalidPassword,
    Unauthorized,
    HashingFailed(String),
}

impl Display for AuthError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::NoPermssions => write!(f, "No permissions"),
            Self::InvalidToken => write!(f, "Invalid token"),
            Self::Unexpected => write!(f, "Unexpected error"),
            Self::InvalidPassword => write!(f, "Password is incorrect"),
            Self::Unauthorized => write!(f, "Authentication is required"),
            Self::HashingFailed(msg) => write!(f, "Password hashing failed: {}", msg),
        }
    }
}

impl std::error::Error for AuthError {}

impl From<argon2::password_hash::Error> for AuthError {
    fn from(value: argon2::password_hash::Error) -> Self {
        AuthError::HashingFailed(value.to_string())
    }
}
