use crate::{auth::get_user_from_header, model::User, AppState};
use axum::{extract::State, http::HeaderMap, routing::get, Json, Router};

pub mod auth;
pub mod member;
pub mod message;
pub mod user;

pub fn routes() -> Router<AppState> {
    Router::new()
        .route("/", get(root))
        .merge(member::routes())
        .merge(auth::routes())
        .merge(user::routes())
        .merge(message::routes())
}

async fn root(
    State(state): State<AppState>,
    headers: HeaderMap,
) -> Result<Json<User>, crate::Error> {
    let user = get_user_from_header(&state.pool, &headers).await?;

    Ok(Json(user))
}
